@@ -4,15 +4,15 @@ open! Postgresql
 
 let _ =
   if Array.length Sys.argv <> 3 then (
-    Printf.printf "\
-      Usage:  dump conninfo table\n\
-      Connect to PostgreSQL with [conninfo] (e.g. \"host=localhost\"),\n\
-      and copy [table] to stdout\n";
+    Printf.printf
+      "Usage:  dump conninfo table\n\
+       Connect to PostgreSQL with [conninfo] (e.g. \"host=localhost\"),\n\
+       and copy [table] to stdout\n";
     exit 1)
 
 let main () =
   let c = new connection ~conninfo:Sys.argv.(1) () in
-  let _ = c#exec ~expect:[Copy_out] ("copy " ^ Sys.argv.(2) ^ " to stdout") in
+  let _ = c#exec ~expect:[ Copy_out ] ("copy " ^ Sys.argv.(2) ^ " to stdout") in
   c#copy_out_channel stdout;
   c#finish
 
