@@ -266,10 +266,6 @@ static inline void np_decr_refcount(np_callback *c) {
 #define get_cancel_obj(v) ((PGcancel *)Field(v, 2))
 #define set_cancel_obj(v, cancel) (Field(v, 2) = (value)cancel)
 
-CAMLprim value PQconn_isnull(value v_conn) {
-  return Val_bool((get_conn(v_conn)) ? 0 : 1);
-}
-
 static inline void free_conn(value v_conn) {
   PGconn *conn = get_conn(v_conn);
   if (conn) {
@@ -800,6 +796,8 @@ CAMLprim value PQgetvalue_stub(value v_res, intnat tup_num, intnat field_num) {
   CAMLparam1(v_res);
   value v_str;
   PGresult *res = get_res(v_res);
+  if (PQgetisnull(res, tup_num, field_num))
+    CAMLreturn(*v_null_param);
   char *str = PQgetvalue(res, tup_num, field_num);
   if (PQfformat(res, field_num) == 0)
     v_str = make_string(str);
@@ -896,6 +894,8 @@ CAMLprim value PQgetescval_stub(value v_res, intnat tup_num, intnat field_num) {
   CAMLparam1(v_res);
   value v_str;
   PGresult *res = get_res(v_res);
+  if (PQgetisnull(res, tup_num, field_num))
+    CAMLreturn(*v_null_param);
   char *str = PQgetvalue(res, tup_num, field_num);
   if (PQfformat(res, field_num) == 0) {
     if (str == NULL || strlen(str) < 2 || !is_bytea_hex_protocol(str))
@@ -961,7 +961,7 @@ CAMLprim intnat PQsendQueryParams_stub(value v_conn, value v_query,
   intnat res;
   copy_binary_params(v_params, v_binary_params, nparams, &formats, &lengths);
   bool binary_result = Bool_val(v_binary_result);
-  res = (nparams == 0)
+  res = (nparams == 0 && !binary_result)
             ? PQsendQuery(conn, query)
             : PQsendQueryParams(conn, query, nparams, param_types, params,
                                 lengths, formats, binary_result);
